"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Notification = exports["default"] = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _Styled = require("./Styled");

var _Header = _interopRequireDefault(require("./Header"));

var _Body = _interopRequireDefault(require("./Body"));

var _Action = _interopRequireDefault(require("./Action"));

var _withProvider = _interopRequireDefault(require("./withProvider"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var AVAILABLE_TYPES = ["info", "warning", "success", "error"];

var Notification = function Notification(_ref) {
  var type = _ref.type,
      data = _ref.data,
      style = _ref.style,
      action = _ref.action,
      darkmode = _ref.darkmode;
  var defaultStyle = {
    color: "rgb(0,151,255)",
    rounded: false,
    animation: "left2right",
    duration: 2
  };
  var title = data.title,
      subtitle = data.subtitle,
      message = data.message;

  var _ref2 = style || defaultStyle,
      animation = _ref2.animation,
      rounded = _ref2.rounded,
      duration = _ref2.duration,
      color = _ref2.color;

  var name = action.name,
      event = action.event;

  if (!AVAILABLE_TYPES.includes(type)) {
    throw new Error(type + ' is not included in notification types');
  }

  if (duration && !(typeof duration === "number") && !Number(duration)) {
    throw new Error("duration should be a number");
  }

  return /*#__PURE__*/_react["default"].createElement(_Styled.Wrapper, {
    type: type,
    animation: animation,
    rounded: rounded,
    color: color,
    darkmode: darkmode,
    duration: duration
  }, /*#__PURE__*/_react["default"].createElement(_Header["default"], {
    title: title,
    subtitle: subtitle
  }), /*#__PURE__*/_react["default"].createElement(_Body["default"], {
    message: message
  }), /*#__PURE__*/_react["default"].createElement(_Action["default"], {
    name: name,
    onClick: event
  }));
};

exports.Notification = Notification;
Notification.propTypes = {
  type: _propTypes["default"].string.isRequired,
  data: _propTypes["default"].object.isRequired,
  style: _propTypes["default"].object,
  action: _propTypes["default"].object.isRequired,
  darkmode: _propTypes["default"].bool
};
Notification.defaultProps = {
  type: "info"
};

var _default = (0, _withProvider["default"])(Notification);

exports["default"] = _default;